/** @file
 *
 * @copyright &copy; Copyright 2007-2008 by Intra2net AG
 * @license commercial
 *
 * info@intra2net.com
 */

#ifndef __I2N_COMMON_SOURCE_TRACK_BASICS_HPP__
#define __I2N_COMMON_SOURCE_TRACK_BASICS_HPP__

#include <string>
#include <boost/current_function.hpp>

/*
** some helper macros
*/

/**
 * macro which encapsulates the construction of a source location.
 */
#define HERE ::I2n::SourceLocation(__FILE__,__LINE__,BOOST_CURRENT_FUNCTION)


namespace I2n
{


/**
 * (helper) struct for providing a source location.
 * Construction should be done with appropriate macros (like @a HERE)
 */
struct SourceLocation
{
   std::string File;
   long        Line;
   std::string FunctionName;

   SourceLocation();

   SourceLocation(
      const std::string& file,
      long  line,
      const std::string& funcname);

   operator bool() const
   {
      return Line>0 and not File.empty() and not FunctionName.empty();
   } // eo operator bool

   std::string get_function_name() const { return FunctionName; }
   std::string get_filename() const { return File; }
   long        get_line_number() const { return Line; }

   std::string get_location_tag() const;

   private:

      mutable std::string LocationTag;

}; // eo struct SourceLocation




} // eo namepsace I2n

#endif
