/** @file
 *
 * tests for the module "containerfunc"
 *
 * (c) Copyright 2007-2008 by Intra2net AG
 * 
 * info@intra2net.com
 */

//#define NOISEDEBUG

#include <string>
#include <vector>
#include <list>
#include <algorithm>

#define BOOST_TEST_DYN_LINK
#include <boost/test/unit_test.hpp>

#include <containerfunc.hpp>

using namespace I2n;

BOOST_AUTO_TEST_SUITE(TestContainerFunc)

BOOST_AUTO_TEST_CASE(FillStringVector)
{
    std::vector< std::string > v;
    BOOST_CHECK_EQUAL( true, v.empty() );

    get_push_back_filler(v)("1")("2")("drei");

    BOOST_CHECK_EQUAL( 3u, v.size() );
    BOOST_CHECK_EQUAL( std::string("2"), v[1]);
    BOOST_CHECK_EQUAL( std::string("drei"), v[2]);
    BOOST_CHECK_EQUAL( std::string("1"), v[0]);

    get_push_back_filler(v)("i3")("i4");

    BOOST_CHECK_EQUAL( 5u, v.size() );
    BOOST_CHECK_EQUAL( std::string("i4"), v[4]);
    BOOST_CHECK_EQUAL( std::string("i3"), v[3]);
} // eo FillStringVector



BOOST_AUTO_TEST_CASE(RetrieveMapKeys)
{
    std::map< int, std::string > map1;
    std::list< int > key_list;
    std::set< int > key_set;

    {
        MapFiller< int, std::string > fill(map1);
        fill
            (1, "one")
            (2, "two")
            (3, "three" )
            (4, "many..." )
        ;
    }
    BOOST_CHECK_EQUAL( 4u, map1.size() );

    get_key_list(map1, key_list);
    BOOST_CHECK_EQUAL( 4u, key_list.size() );
    BOOST_CHECK( std::find(key_list.begin(), key_list.end(), 1) != key_list.end() );
    BOOST_CHECK( std::find(key_list.begin(), key_list.end(), 2) != key_list.end() );
    BOOST_CHECK( std::find(key_list.begin(), key_list.end(), 3) != key_list.end() );
    BOOST_CHECK( std::find(key_list.begin(), key_list.end(), 4) != key_list.end() );

    get_key_set(map1, key_set);
    BOOST_CHECK_EQUAL( 4u, key_set.size() );
    BOOST_CHECK( key_set.find(1) != key_set.end() );
    BOOST_CHECK( key_set.find(2) != key_set.end() );
    BOOST_CHECK( key_set.find(3) != key_set.end() );
    BOOST_CHECK( key_set.find(4) != key_set.end() );
} // RetrieveMapKeys()

BOOST_AUTO_TEST_SUITE_END()
